@@ -34,8 +34,8 @@ GvaScript.ChoiceList = function(choices, options) {
   this.hasPaginator = this.options.paginator != null;
   this.pageSize = (
                     // the step size of the paginator if any
-                    (this.hasPaginator && this.options.paginator.options.step) 
-                    ||  
+                    (this.hasPaginator && this.options.paginator.options.step)
+                    ||
                     // scroll count
                     this.options.scrollCount
                   );
@@ -49,28 +49,28 @@ GvaScript.ChoiceList = function(choices, options) {
       DOWN:      this._highlightDelta.bindAsEventListener(this, 1),
       UP:        this._highlightDelta.bindAsEventListener(this, -1),
 
-      PAGE_DOWN: this._highlightDelta.bindAsEventListener(this, this.pageSize), 
+      PAGE_DOWN: this._highlightDelta.bindAsEventListener(this, this.pageSize),
       PAGE_UP:   this._highlightDelta.bindAsEventListener(this, -this.pageSize),
 
       HOME:      this._jumpToIndex.bindAsEventListener(this, 0),
-      END:       this._jumpToIndex.bindAsEventListener(this, 99999), 
+      END:       this._jumpToIndex.bindAsEventListener(this, 99999),
 
       RETURN:    this._returnHandler .bindAsEventListener(this),
       ESCAPE:    this._escapeHandler .bindAsEventListener(this)
     }
   };
-  
+
   if(this.hasPaginator) {
     // next/prev page
-    this.reuse.navigationRules.RIGHT  
+    this.reuse.navigationRules.RIGHT
         = this._highlightDelta.bindAsEventListener(this, this.pageSize)
-    this.reuse.navigationRules.LEFT   
+    this.reuse.navigationRules.LEFT
         = this._highlightDelta.bindAsEventListener(this, -this.pageSize);
 
     // first/last page
     this.reuse.navigationRules.C_HOME
         = this._jumpToPage.bindAsEventListener(this, 0);
-    this.reuse.navigationRules.C_END  
+    this.reuse.navigationRules.C_END
         = this._jumpToPage.bindAsEventListener(this, 99999);
   }
 };
@@ -90,7 +90,7 @@ GvaScript.ChoiceList.prototype = {
 
     this.container = containerElem;
     this.container.choiceList = this;
-    
+
     Element.update(this.container, this.htmlForChoices());
 
     // mouse events on choice items will bubble up to the container
@@ -106,19 +106,19 @@ GvaScript.ChoiceList.prototype = {
     }
     else {
       this.keymap = new GvaScript.KeyMap(this.reuse.navigationRules);
-      var target = this.container.tabIndex == undefined 
+      var target = this.container.tabIndex == undefined
                      ? document
                      : this.container;
       this.keymap.observe("keydown", target);
     }
     // POTENTIAL PROBLEM HERE : the keymap may stay active
-    // even after the choiceList is deleted (may yield memory leaks and 
+    // even after the choiceList is deleted (may yield memory leaks and
     // inconsistent behaviour). But we have no "destructor", so how
     // can we unregister the keymap ?
 
 
-    // highlight the first choice
-    this._highlightChoiceNum(0, false);
+    // highlight the initial value or the first choice
+    this._highlightChoiceNum(this.currentHighlightedIndex || 0, false);
   },
 
   updateContainer: function(container, list) {
@@ -127,11 +127,11 @@ GvaScript.ChoiceList.prototype = {
     this._highlightChoiceNum(0, true);
   },
 
-  htmlForChoices: function(){ // creates the innerHTML 
+  htmlForChoices: function(){ // creates the innerHTML
     var html = "";
     for (var i = 0; i < this.choices.length; i++) {
       var choice = this.choices[i];
-      var label  = 
+      var label  =
         typeof choice == "string" ? choice : choice[this.options.labelField];
 
       var id = this.container.id ? this.container.id + "." : '';
@@ -142,11 +142,11 @@ GvaScript.ChoiceList.prototype = {
   },
 
   choiceElementHTML: function(label, id) {
-    return "<" + this.options.choiceItemTagName + " class='" + this.classes.choiceItem +  "' id='" + id + "'>" 
+    return "<" + this.options.choiceItemTagName + " class='" + this.classes.choiceItem +  "' id='" + id + "'>"
            + label + "</" + this.options.choiceItemTagName + ">";
   },
 
-  fireEvent: GvaScript.fireEvent, // must be copied here for binding "this" 
+  fireEvent: GvaScript.fireEvent, // must be copied here for binding "this"
 
 
 //----------------------------------------------------------------------
@@ -169,7 +169,7 @@ GvaScript.ChoiceList.prototype = {
 
 
   //----------------------------------------------------------------------
-  // highlighting 
+  // highlighting
   //----------------------------------------------------------------------
 
   _highlightChoiceNum: function(newIndex, autoScroll) {
@@ -177,17 +177,17 @@ GvaScript.ChoiceList.prototype = {
     // do nothing if newIndex is invalid
     if (newIndex > this.choices.length - 1) return;
 
-    Element.removeClassName(this._choiceElem(this.currentHighlightedIndex), 
+    Element.removeClassName(this._choiceElem(this.currentHighlightedIndex),
                             this.classes.choiceHighlight);
     this.currentHighlightedIndex = newIndex;
     var elem = this._choiceElem(newIndex);
-    // not to throw an arrow when user is holding an UP/DN keys while 
+    // not to throw an arrow when user is holding an UP/DN keys while
     // paginating
     if(! $(elem)) return;
 
     Element.addClassName(elem, this.classes.choiceHighlight);
 
-    if (autoScroll) 
+    if (autoScroll)
       Element.autoScroll(elem, this.container, 30); // 30%
 
     this.fireEvent({type: "Highlight", index: newIndex}, elem, this.container);
@@ -198,19 +198,19 @@ GvaScript.ChoiceList.prototype = {
     var autoScroll = event && event.keyName; // autoScroll only for key events
 
     this._highlightChoiceNum(
-        Math.max(0, Math.min(this.choices.length-1, nextIndex)), 
+        Math.max(0, Math.min(this.choices.length-1, nextIndex)),
         autoScroll
     );
-                             
+
     if (event) Event.stop(event);
   },
 
-  
-  // TODO: jump to page numbers would be a nice addition 
+
+  // TODO: jump to page numbers would be a nice addition
   _jumpToPage: function(event, pageIndex) {
     if(pageIndex <=1) return this.options.paginator.getFirstPage();
     if(pageIndex == 99999) return this.options.paginator.getLastPage();
-    
+
     if (event) Event.stop(event);
   },
 
@@ -218,7 +218,7 @@ GvaScript.ChoiceList.prototype = {
   _highlightDelta: function(event, deltax, deltay) {
     var currentIndex = this.currentHighlightedIndex;
     var nextIndex    = currentIndex + deltax;
-    
+
     // first try to flip a page
     // if first page -> go top of list
     if (nextIndex < 0) {
@@ -230,17 +230,17 @@ GvaScript.ChoiceList.prototype = {
 
     if (nextIndex >= this.choices.length) {
         if(this.hasPaginator) {
-            if(this.options.paginator.getNextPage()) return; 
+            if(this.options.paginator.getNextPage()) return;
         }
         nextIndex = this.choices.length -1;
     }
-    
+
     // we're still on the same page
     this._jumpToIndex(event, nextIndex);
   },
 
   //----------------------------------------------------------------------
-  // navigation 
+  // navigation
   //----------------------------------------------------------------------
 
   _findChoiceItem: function(event) { // walk up DOM to find mouse target
@@ -278,9 +278,9 @@ GvaScript.ChoiceList.prototype = {
       // check if choice is selected
       if (this.currentHighlightedIndex == newIndex) {
         // selected -> fire ping event
-        var toStop = this.fireEvent({type : "Ping", 
-                                    index: this._choiceIndex(elem)}, 
-                                    elem, 
+        var toStop = this.fireEvent({type : "Ping",
+                                    index: this._choiceIndex(elem)},
+                                    elem,
                                     this.container);
         Event.detailedStop(event, toStop || Event.stopAll);
       }
@@ -295,7 +295,7 @@ GvaScript.ChoiceList.prototype = {
     var index = this.currentHighlightedIndex;
     if (index != undefined) {
       var elem = this._choiceElem(index);
-      var toStop = this.fireEvent({type : "Ping", 
+      var toStop = this.fireEvent({type : "Ping",
                                    index: index}, elem, this.container);
       Event.detailedStop(event, toStop || Event.stopAll);
     }
